pub unsafe extern "C" fn wxd_CheckListBox_GetString(
clbox: *const wxd_CheckListBox_t,
index: usize,
buffer: *mut c_char,
buffer_len: usize,
) -> c_intExpand description
Retrieves the string at the specified index from the wxCheckListBox. Returns the length of the string copied into the buffer, excluding the null terminator, if any error, -1 returned. If the buffer is too small, it copies as much as fits and returns the required size. If the index is out of bounds, returns 0 and does not modify the buffer.