pub unsafe extern "C" fn wxd_ArrayString_GetString(
array: *const wxd_ArrayString_t,
index: c_int,
buffer: *mut c_char,
bufferLen: usize,
) -> c_intExpand description
Get string at specified index. Returns the real length of the string, excluding the null terminator, if any error, -1 returned. If the returned length is negative, indicates an error (invalid index or parameters). If buffer is non-null and bufferLen > 0, copies up to bufferLen - 1 characters and null-terminates. If buffer is null or bufferLen == 0, does not copy anything.