wxd_DataViewTreeModel_CreateWithCallbacks

Function wxd_DataViewTreeModel_CreateWithCallbacks 

pub unsafe extern "C" fn wxd_DataViewTreeModel_CreateWithCallbacks(
    callbacks: *const wxd_DataViewTreeModel_Callbacks,
) -> *mut wxd_DataViewModel_t
@brief Creates a new custom tree model with callbacks, the returned model has ref count 1, the caller is responsible for releasing it when done with wxd_DataViewModel_Release.